@@ -52,3 +52,12 @@ class MinimalPyflakes(features.Feature):
 
 
 minimal_pyflakes = MinimalPyflakes()
+
+
+class AtLeastUbuntu(features.UbuntuPlatformFeature):
+
+    def _probe(self):
+        return (self._name == 'Ubuntu' and self.expected_id <= self.actual_id)
+
+
+at_least_trusty = AtLeastUbuntu('trusty')
