@@ -41,7 +41,7 @@ class TestImportFromPath(unittest.TestCase):
         with self.assertRaises(TypeError) as cm:
             self.loader.importFromPath('.')
         self.assertEqual("relative imports require the 'package' argument",
-                         cm.exception.message)
+                         unicode(cm.exception))
 
     def test_weird_path(self):
         d = './foo.bar/baz'
@@ -59,7 +59,7 @@ Traceback (most recent call last):
     __import__(name)
 ImportError: No module named foo.bar.baz
 ''',
-                                              cm.exception.message)
+                                              unicode(cm.exception))
 
     def test_invalid_python_file(self):
         with open('foo.py', 'w') as f:
@@ -81,7 +81,7 @@ Traceback (most recent call last):
     __import__(name)
 ImportError: No module named foo
 ''',
-                                              cm.exception.message)
+                                              unicode(cm.exception))
 
     def test_unknown_file(self):
         with self.assertRaises(ImportError) as cm:
@@ -95,7 +95,7 @@ Traceback (most recent call last):
     __import__(name)
 ImportError: No module named foo
 ''',
-                                              cm.exception.message)
+                                              unicode(cm.exception))
 
     def test_valid_file(self):
         self.assertIs(None, sys.modules.get('foo', None))
@@ -142,7 +142,7 @@ imported = True
         with self.assertRaises(ImportError) as cm:
             sys_path_entry, rel_path = self.loader.packageSysPathFromName(
                 'foo')
-        self.assertEqual('No module named foo', cm.exception.message)
+        self.assertEqual('No module named foo', unicode(cm.exception))
 
 
 class TestSortNames(unittest.TestCase):
